import * as i0 from '@angular/core';
import { Injectable, Component, Input, NgModule } from '@angular/core';
import { trigger, transition, style, animate } from '@angular/animations';
import * as XLSX from 'xlsx';
import * as i1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as i2 from '@angular/common';
import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';

class SsrTableService {
    constructor() { }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SsrTableService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SsrTableService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SsrTableService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class SsrTableComponent {
    constructor() {
        this.data = [];
        this.columns = [];
        this.visibleColumns = {};
        this.allColumns = [];
        this.displayedColumns = [];
        this.searchQuery = '';
        this.filteredData = [];
        this.paginatedData = [];
        this.currentPage = 1;
        this.pageSize = 5;
        this.pageSizes = [5, 10, 15, 20];
        this.sortDirection = {}; // true for ascending, false for descending
        this.isExporting = false;
        this.expandedRow = null; // Tracks the currently expanded row
    }
    ngOnInit() {
        this.initializeColumns();
        this.filteredData = [...this.data];
        this.applyPagination();
    }
    initializeColumns() {
        this.allColumns = this.columns;
        this.visibleColumns = this.allColumns.reduce((acc, col) => {
            acc[col] = true; // Default to true for visibility
            this.sortDirection[col] = true;
            return acc;
        }, {});
        this.updateDisplayedColumns();
    }
    updateDisplayedColumns() {
        this.displayedColumns = this.allColumns.filter(col => this.visibleColumns[col]);
        this.applyPagination();
    }
    applySearch() {
        const query = this.searchQuery.toLowerCase();
        this.filteredData = this.data.filter(row => Object.keys(row).some(key => String(row[key]).toLowerCase().includes(query)));
        this.applyPagination();
    }
    resetSearch() {
        this.searchQuery = '';
        this.applySearch();
    }
    sortTable(column) {
        this.filteredData.sort((a, b) => {
            const comparison = a[column] > b[column] ? 1 : a[column] < b[column] ? -1 : 0;
            return this.sortDirection[column] ? comparison : -comparison;
        });
        this.sortDirection[column] = !this.sortDirection[column]; // Toggle sort direction
        this.applyPagination();
    }
    applyPagination() {
        const startIndex = (this.currentPage - 1) * this.pageSize;
        const endIndex = this.currentPage * this.pageSize;
        this.paginatedData = this.filteredData.slice(startIndex, endIndex);
    }
    prevPage() {
        if (this.currentPage > 1) {
            this.currentPage--;
            this.applyPagination();
        }
    }
    nextPage() {
        if (this.currentPage * this.pageSize < this.filteredData.length) {
            this.currentPage++;
            this.applyPagination();
        }
    }
    get totalPages() {
        return Math.ceil(this.filteredData.length / this.pageSize);
    }
    async downloadTable() {
        this.isExporting = true;
        const worksheet = XLSX.utils.json_to_sheet(this.filteredData);
        const workbook = XLSX.utils.book_new();
        XLSX.utils.book_append_sheet(workbook, worksheet, 'Table Data');
        XLSX.writeFile(workbook, 'table-data.xlsx');
        this.isExporting = false;
    }
    toggleRow(row) {
        if (this.expandedRow === row) {
            this.expandedRow = null; // Collapse if already expanded
        }
        else {
            this.expandedRow = row; // Expand new row
            this.fetchAdditionalData(row); // Fetch additional data for the row
        }
    }
    fetchAdditionalData(row) {
        setTimeout(() => {
            row.additionalData = {
                details: 'Additional data fetched dynamically.',
                timestamp: new Date().toLocaleString(),
            };
        }, 500); // Simulate network delay
    }
    downloadRow(row) {
        const worksheet = XLSX.utils.json_to_sheet([row]);
        const workbook = XLSX.utils.book_new();
        XLSX.utils.book_append_sheet(workbook, worksheet, 'Row Data');
        XLSX.writeFile(workbook, `row-data-${row.id}.xlsx`);
    }
    copyRow(row) {
        navigator.clipboard.writeText(JSON.stringify(row)).then(() => {
            row.isCopied = true;
            setTimeout(() => (row.isCopied = false), 2000); // Reset after 2 seconds
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SsrTableComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SsrTableComponent, selector: "lib-ssr-table", inputs: { data: "data", columns: "columns" }, ngImport: i0, template: "<div class=\"table-container\">\n  <div class=\"controls\">\n    <div class=\"search-bar\">\n      <input\n        type=\"text\"\n        placeholder=\"Search\"\n        [(ngModel)]=\"searchQuery\"\n        (input)=\"applySearch()\"\n      />\n      <button (click)=\"resetSearch()\" aria-label=\"Clear Search\">Clear</button>\n    </div>\n    <div class=\"column-controls\">\n      <label *ngFor=\"let column of allColumns\">\n        <input\n          type=\"checkbox\"\n          [(ngModel)]=\"visibleColumns[column]\"\n          (change)=\"updateDisplayedColumns()\"\n        />\n        {{ column }}\n      </label>\n    </div>\n    <div class=\"actions\">\n      <button (click)=\"downloadTable()\" [disabled]=\"isExporting\" aria-label=\"Download Table\">\n        {{ isExporting ? 'Exporting...' : 'Download' }}\n      </button>\n    </div>\n  </div>\n\n  <table class=\"custom-table\">\n    <thead>\n      <tr>\n        <th *ngFor=\"let column of displayedColumns\" (click)=\"sortTable(column)\">\n          {{ column | titlecase }}\n          <span class=\"sort-icon\">{{ sortDirection[column] ? '\u25B2' : '\u25BC' }}</span>\n        </th>\n      </tr>\n    </thead>\n    <tbody>\n      <tr *ngFor=\"let row of paginatedData\">\n        <td *ngFor=\"let column of displayedColumns\">\n          {{ row[column] }}\n        </td>\n        <td *ngIf=\"visibleColumns['action']\" style=\"display: flex;align-items: center;justify-content: center;\">\n          <button (click)=\"toggleRow(row)\" style=\"align-items: center; display: flex;background-color: rgb(175,15,79);cursor: pointer; gap:1rem \">\n            Expand\n            <svg xmlns=\"http://www.w3.org/2000/svg\" fill=\"none\" viewBox=\"0 0 24 24\" stroke-width=\"1.5\" stroke=\"currentColor\" class=\"size-6\" style=\"width: 1.5rem;\">\n              <path stroke-linecap=\"round\" stroke-linejoin=\"round\" d=\"M3 4.5h14.25M3 9h9.75M3 13.5h9.75m4.5-4.5v12m0 0-3.75-3.75M17.25 21 21 17.25\" />\n            </svg>\n          </button>\n        </td>\n        <td *ngIf=\"visibleColumns['download']\">\n          <div style=\"display: flex;justify-content: center;align-items: center;\">\n            <button style=\"align-items: center; display: flex;background-color: rgb(175,15,79);cursor: pointer; gap:1rem \" (click)=\"downloadRow(row)\">\n              Download\n              <svg xmlns=\"http://www.w3.org/2000/svg\" fill=\"none\" viewBox=\"0 0 24 24\" stroke-width=\"1.5\" stroke=\"currentColor\" class=\"size-6\" style=\"width: 1.5rem;\">\n                <path stroke-linecap=\"round\" stroke-linejoin=\"round\" d=\"M3 16.5v2.25A2.25 2.25 0 0 0 5.25 21h13.5A2.25 2.25 0 0 0 21 18.75V16.5M16.5 12 12 16.5m0 0L7.5 12m4.5 4.5V3\" />\n              </svg>\n            </button>\n          </div>\n        </td>\n        <td *ngIf=\"visibleColumns['copy']\">\n          <svg xmlns=\"http://www.w3.org/2000/svg\" (click)=\"copyRow(row)\" fill=\"none\" viewBox=\"0 0 24 24\" stroke-width=\"1.5\" stroke=\"currentColor\" class=\"size-6\" style=\"width:1.7rem\">\n            <path stroke-linecap=\"round\" stroke-linejoin=\"round\" d=\"M9 12h3.75M9 15h3.75M9 18h3.75m3 .75H18a2.25 2.25 0 0 0 2.25-2.25V6.108c0-1.135-.845-2.098-1.976-2.192a48.424 48.424 0 0 0-1.123-.08m-5.801 0c-.065.21-.1.433-.1.664 0 .414.336.75.75.75h4.5a.75.75 0 0 0 .75-.75 2.25 2.25 0 0 0-.1-.664m-5.8 0A2.251 2.251 0 0 1 13.5 2.25H15c1.012 0 1.867.668 2.15 1.586m-5.8 0c-.376.023-.75.05-1.124.08C9.095 4.01 8.25 4.973 8.25 6.108V8.25m0 0H4.875c-.621 0-1.125.504-1.125 1.125v11.25c0 .621.504 1.125 1.125 1.125h9.75c.621 0 1.125-.504 1.125-1.125V9.375c0-.621-.504-1.125-1.125-1.125H8.25ZM6.75 12h.008v.008H6.75V12Zm0 3h.008v.008H6.75V15Zm0 3h.008v.008H6.75V18Z\" />\n          </svg>\n          <span *ngIf=\"row.isCopied\" style=\"color: green;\">Copied</span>\n        </td>\n      </tr>\n    </tbody>\n  </table>\n</div>\n", styles: [".table-container{position:relative;padding:20px;background:linear-gradient(145deg,#f8d7eb,#f8e8f3);border-radius:10px;color:#090613;font-family:Arial,sans-serif;box-shadow:0 10px 20px #0003,inset 0 -2px 5px #ffffff80}.table-container .title{text-align:center;font-size:2rem;color:#3b4564;margin-bottom:20px;text-shadow:1px 2px 4px rgba(0,0,0,.3)}.table-container canvas#three-js-background{position:absolute;top:0;left:0;width:100%;height:100%;z-index:0}.table-container .custom-table{position:relative;z-index:1;width:100%;border-collapse:collapse;border-spacing:0;background:#fff;overflow:hidden;box-shadow:0 10px 30px #0003}.table-container .custom-table :is(th,td){padding:6px 12px;text-align:center}.table-container .custom-table th{background:linear-gradient(145deg,#c2185b,#a90c4b);color:#fff;text-transform:uppercase;font-weight:700;text-shadow:1px 2px 4px rgba(0,0,0,.3)}.table-container .custom-table tbody tr{transition:transform .3s ease,box-shadow .3s ease}.table-container .custom-table tbody tr:hover{transform:translateY(-1px);box-shadow:0 8px 15px #0000004d,0 0 10px #fff6}.table-container .custom-table tbody tr:nth-child(2n){background:linear-gradient(145deg,#e19bc6,#f2d2e1)}.table-container .custom-table tbody tr:nth-child(odd){background:linear-gradient(145deg,#e3bad3,#f9e6f3)}.table-container .custom-table td{background:#f0f0f0cc;box-shadow:inset 0 -2px 5px #0000001a,inset 0 2px 5px #ffffff80}.table-container .footer{display:flex;justify-content:space-between;align-items:center;padding:10px 20px;background:linear-gradient(145deg,#db044be5,#b6035de5);border-top:1px solid #ccc;color:#fff;font-size:14px}.table-container .footer .row-size-adjuster{display:flex;align-items:center;gap:10px}.table-container .footer label{color:#f5f5f5;font-weight:700}.table-container .footer input[type=range]{accent-color:rgba(255,5,159,.678)}.table-container .footer button{padding:5px 10px;border:none;border-radius:4px;background-color:#ac006aad;color:#fff;font-size:14px;transition:all .3s ease}.table-container .footer button:hover:not(:disabled){background-color:#840754cc}.table-container .footer button:disabled{background-color:#dbccd5ad}.controls{display:flex;flex-wrap:wrap;justify-content:space-between;gap:10px;margin-bottom:20px}.controls input[type=text],.controls select{padding:8px 12px;font-size:14px;border:1px solid #ccc;border-radius:4px;width:200px;transition:border-color .3s ease}.controls input[type=text]:focus,.controls select:focus{outline:none;border-color:#4372a3;box-shadow:0 0 4px #4372a366}.controls button{padding:8px 15px;border:none;border-radius:4px;background-color:#4372a3;color:#fff;font-size:14px;cursor:pointer;transition:background-color .3s ease,transform .1s ease}.controls button:hover{background-color:#2e5a85}.controls button:active{transform:scale(.98)}@media (max-width: 768px){.controls{flex-direction:column;align-items:center}.controls input[type=text],.controls select{width:100%}}.row-size-adjuster{display:flex;align-items:center;justify-content:center;margin-top:10px}.row-size-adjuster label{margin-right:10px;color:#2f7593}.row-size-adjuster tbody tr.expanded{background:linear-gradient(145deg,#e0f7fa,#e1f5fe)}.row-size-adjuster .expanded-content{padding:10px;font-size:14px;color:#333;background:#ab0e5b;box-shadow:inset 0 -2px 5px #0000001a,inset 0 2px 5px #ffffff80;border-radius:4px}.row-size-adjuster .expand{background-color:#b10870;color:#000}button{padding:5px 10px;border:none;border-radius:4px;background-color:#b10870;color:#fff;font-size:14px;transition:all .3s ease}button:hover:not(:disabled){background-color:#840754cc}button:disabled{background-color:#dbccd5ad}mat-form-field{width:100%}mat-option{display:flex;align-items:center}mat-checkbox{margin-right:8px}tr{height:50px;transition:height .4s ease-in-out,background-color .4s ease-in-out;background-color:#fff;cursor:pointer}.expanded-row{height:150px;transition:height .4s ease-in-out,background-color .4s ease-in-out;background-color:#f8ddee}tr td{vertical-align:top;padding:6px}.expanded-data-row{background-color:#f9f9f9;opacity:1;visibility:hidden;transition:opacity .7s ease-in-out,visibility .7s ease-in-out}.expanded-content{display:flex;flex-wrap:wrap;gap:1rem;background-color:#ab0e5b;padding:1rem;visibility:hidden;transition:opacity .7s ease-in-out,visibility .7s ease-in-out}.expanded-content .container p{margin:0;font-size:.9rem;visibility:visible;transition:opacity .7s ease-in-out,visibility .7s ease-in-out}.expanded-content{display:flex;flex-wrap:wrap;gap:1rem;background-color:#ab0e5b;padding:1rem;border-radius:4px;visibility:visible;transition:opacity .7s ease-in-out,visibility .7s ease-in-out;transition:background-color .3s ease,border-color .3s ease}.expanded-content .container{flex:1 1 calc(25% - 1rem);min-width:150px;background-color:#fff;border-radius:4px;padding:.5rem;box-shadow:0 2px 4px #0000001a;transition:opacity .7s ease-in-out,visibility .7s ease-in-out}.expanded-content .container:hover{background-color:#f0f0f0;box-shadow:0 4px 8px #00000026;transform:translateY(-2px)}.rectangular-container{display:grid;grid-template-columns:repeat(3,1fr);gap:15px;padding:20px;background-color:#f9f9f9;border-radius:8px;box-shadow:0 4px 8px #0000001a}.info-box{background:#fff;border:1px solid #ececec;border-radius:6px;box-shadow:0 5px 10px #00000026;padding:10px 15px;transition:transform .2s,box-shadow .2s}.info-box:hover{transform:translateY(-5px);box-shadow:0 8px 15px #00000040}.info-box p{margin:0;font-family:Arial,sans-serif;font-size:14px;color:#333}strong.container{color:#af0f4f;font-weight:700}.svg_icon{width:1.5rem;display:flex;margin-top:-1.7rem;margin-left:13.5rem}\n"], dependencies: [{ kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: i2.TitleCasePipe, name: "titlecase" }], animations: [
            trigger('fadeInOut', [
                transition(':enter', [
                    style({ opacity: 0 }),
                    animate('300ms ease-in', style({ opacity: 1 })),
                ]),
                transition(':leave', [
                    animate('300ms ease-out', style({ opacity: 0 })),
                ]),
            ]),
        ] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SsrTableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-ssr-table', animations: [
                        trigger('fadeInOut', [
                            transition(':enter', [
                                style({ opacity: 0 }),
                                animate('300ms ease-in', style({ opacity: 1 })),
                            ]),
                            transition(':leave', [
                                animate('300ms ease-out', style({ opacity: 0 })),
                            ]),
                        ]),
                    ], template: "<div class=\"table-container\">\n  <div class=\"controls\">\n    <div class=\"search-bar\">\n      <input\n        type=\"text\"\n        placeholder=\"Search\"\n        [(ngModel)]=\"searchQuery\"\n        (input)=\"applySearch()\"\n      />\n      <button (click)=\"resetSearch()\" aria-label=\"Clear Search\">Clear</button>\n    </div>\n    <div class=\"column-controls\">\n      <label *ngFor=\"let column of allColumns\">\n        <input\n          type=\"checkbox\"\n          [(ngModel)]=\"visibleColumns[column]\"\n          (change)=\"updateDisplayedColumns()\"\n        />\n        {{ column }}\n      </label>\n    </div>\n    <div class=\"actions\">\n      <button (click)=\"downloadTable()\" [disabled]=\"isExporting\" aria-label=\"Download Table\">\n        {{ isExporting ? 'Exporting...' : 'Download' }}\n      </button>\n    </div>\n  </div>\n\n  <table class=\"custom-table\">\n    <thead>\n      <tr>\n        <th *ngFor=\"let column of displayedColumns\" (click)=\"sortTable(column)\">\n          {{ column | titlecase }}\n          <span class=\"sort-icon\">{{ sortDirection[column] ? '\u25B2' : '\u25BC' }}</span>\n        </th>\n      </tr>\n    </thead>\n    <tbody>\n      <tr *ngFor=\"let row of paginatedData\">\n        <td *ngFor=\"let column of displayedColumns\">\n          {{ row[column] }}\n        </td>\n        <td *ngIf=\"visibleColumns['action']\" style=\"display: flex;align-items: center;justify-content: center;\">\n          <button (click)=\"toggleRow(row)\" style=\"align-items: center; display: flex;background-color: rgb(175,15,79);cursor: pointer; gap:1rem \">\n            Expand\n            <svg xmlns=\"http://www.w3.org/2000/svg\" fill=\"none\" viewBox=\"0 0 24 24\" stroke-width=\"1.5\" stroke=\"currentColor\" class=\"size-6\" style=\"width: 1.5rem;\">\n              <path stroke-linecap=\"round\" stroke-linejoin=\"round\" d=\"M3 4.5h14.25M3 9h9.75M3 13.5h9.75m4.5-4.5v12m0 0-3.75-3.75M17.25 21 21 17.25\" />\n            </svg>\n          </button>\n        </td>\n        <td *ngIf=\"visibleColumns['download']\">\n          <div style=\"display: flex;justify-content: center;align-items: center;\">\n            <button style=\"align-items: center; display: flex;background-color: rgb(175,15,79);cursor: pointer; gap:1rem \" (click)=\"downloadRow(row)\">\n              Download\n              <svg xmlns=\"http://www.w3.org/2000/svg\" fill=\"none\" viewBox=\"0 0 24 24\" stroke-width=\"1.5\" stroke=\"currentColor\" class=\"size-6\" style=\"width: 1.5rem;\">\n                <path stroke-linecap=\"round\" stroke-linejoin=\"round\" d=\"M3 16.5v2.25A2.25 2.25 0 0 0 5.25 21h13.5A2.25 2.25 0 0 0 21 18.75V16.5M16.5 12 12 16.5m0 0L7.5 12m4.5 4.5V3\" />\n              </svg>\n            </button>\n          </div>\n        </td>\n        <td *ngIf=\"visibleColumns['copy']\">\n          <svg xmlns=\"http://www.w3.org/2000/svg\" (click)=\"copyRow(row)\" fill=\"none\" viewBox=\"0 0 24 24\" stroke-width=\"1.5\" stroke=\"currentColor\" class=\"size-6\" style=\"width:1.7rem\">\n            <path stroke-linecap=\"round\" stroke-linejoin=\"round\" d=\"M9 12h3.75M9 15h3.75M9 18h3.75m3 .75H18a2.25 2.25 0 0 0 2.25-2.25V6.108c0-1.135-.845-2.098-1.976-2.192a48.424 48.424 0 0 0-1.123-.08m-5.801 0c-.065.21-.1.433-.1.664 0 .414.336.75.75.75h4.5a.75.75 0 0 0 .75-.75 2.25 2.25 0 0 0-.1-.664m-5.8 0A2.251 2.251 0 0 1 13.5 2.25H15c1.012 0 1.867.668 2.15 1.586m-5.8 0c-.376.023-.75.05-1.124.08C9.095 4.01 8.25 4.973 8.25 6.108V8.25m0 0H4.875c-.621 0-1.125.504-1.125 1.125v11.25c0 .621.504 1.125 1.125 1.125h9.75c.621 0 1.125-.504 1.125-1.125V9.375c0-.621-.504-1.125-1.125-1.125H8.25ZM6.75 12h.008v.008H6.75V12Zm0 3h.008v.008H6.75V15Zm0 3h.008v.008H6.75V18Z\" />\n          </svg>\n          <span *ngIf=\"row.isCopied\" style=\"color: green;\">Copied</span>\n        </td>\n      </tr>\n    </tbody>\n  </table>\n</div>\n", styles: [".table-container{position:relative;padding:20px;background:linear-gradient(145deg,#f8d7eb,#f8e8f3);border-radius:10px;color:#090613;font-family:Arial,sans-serif;box-shadow:0 10px 20px #0003,inset 0 -2px 5px #ffffff80}.table-container .title{text-align:center;font-size:2rem;color:#3b4564;margin-bottom:20px;text-shadow:1px 2px 4px rgba(0,0,0,.3)}.table-container canvas#three-js-background{position:absolute;top:0;left:0;width:100%;height:100%;z-index:0}.table-container .custom-table{position:relative;z-index:1;width:100%;border-collapse:collapse;border-spacing:0;background:#fff;overflow:hidden;box-shadow:0 10px 30px #0003}.table-container .custom-table :is(th,td){padding:6px 12px;text-align:center}.table-container .custom-table th{background:linear-gradient(145deg,#c2185b,#a90c4b);color:#fff;text-transform:uppercase;font-weight:700;text-shadow:1px 2px 4px rgba(0,0,0,.3)}.table-container .custom-table tbody tr{transition:transform .3s ease,box-shadow .3s ease}.table-container .custom-table tbody tr:hover{transform:translateY(-1px);box-shadow:0 8px 15px #0000004d,0 0 10px #fff6}.table-container .custom-table tbody tr:nth-child(2n){background:linear-gradient(145deg,#e19bc6,#f2d2e1)}.table-container .custom-table tbody tr:nth-child(odd){background:linear-gradient(145deg,#e3bad3,#f9e6f3)}.table-container .custom-table td{background:#f0f0f0cc;box-shadow:inset 0 -2px 5px #0000001a,inset 0 2px 5px #ffffff80}.table-container .footer{display:flex;justify-content:space-between;align-items:center;padding:10px 20px;background:linear-gradient(145deg,#db044be5,#b6035de5);border-top:1px solid #ccc;color:#fff;font-size:14px}.table-container .footer .row-size-adjuster{display:flex;align-items:center;gap:10px}.table-container .footer label{color:#f5f5f5;font-weight:700}.table-container .footer input[type=range]{accent-color:rgba(255,5,159,.678)}.table-container .footer button{padding:5px 10px;border:none;border-radius:4px;background-color:#ac006aad;color:#fff;font-size:14px;transition:all .3s ease}.table-container .footer button:hover:not(:disabled){background-color:#840754cc}.table-container .footer button:disabled{background-color:#dbccd5ad}.controls{display:flex;flex-wrap:wrap;justify-content:space-between;gap:10px;margin-bottom:20px}.controls input[type=text],.controls select{padding:8px 12px;font-size:14px;border:1px solid #ccc;border-radius:4px;width:200px;transition:border-color .3s ease}.controls input[type=text]:focus,.controls select:focus{outline:none;border-color:#4372a3;box-shadow:0 0 4px #4372a366}.controls button{padding:8px 15px;border:none;border-radius:4px;background-color:#4372a3;color:#fff;font-size:14px;cursor:pointer;transition:background-color .3s ease,transform .1s ease}.controls button:hover{background-color:#2e5a85}.controls button:active{transform:scale(.98)}@media (max-width: 768px){.controls{flex-direction:column;align-items:center}.controls input[type=text],.controls select{width:100%}}.row-size-adjuster{display:flex;align-items:center;justify-content:center;margin-top:10px}.row-size-adjuster label{margin-right:10px;color:#2f7593}.row-size-adjuster tbody tr.expanded{background:linear-gradient(145deg,#e0f7fa,#e1f5fe)}.row-size-adjuster .expanded-content{padding:10px;font-size:14px;color:#333;background:#ab0e5b;box-shadow:inset 0 -2px 5px #0000001a,inset 0 2px 5px #ffffff80;border-radius:4px}.row-size-adjuster .expand{background-color:#b10870;color:#000}button{padding:5px 10px;border:none;border-radius:4px;background-color:#b10870;color:#fff;font-size:14px;transition:all .3s ease}button:hover:not(:disabled){background-color:#840754cc}button:disabled{background-color:#dbccd5ad}mat-form-field{width:100%}mat-option{display:flex;align-items:center}mat-checkbox{margin-right:8px}tr{height:50px;transition:height .4s ease-in-out,background-color .4s ease-in-out;background-color:#fff;cursor:pointer}.expanded-row{height:150px;transition:height .4s ease-in-out,background-color .4s ease-in-out;background-color:#f8ddee}tr td{vertical-align:top;padding:6px}.expanded-data-row{background-color:#f9f9f9;opacity:1;visibility:hidden;transition:opacity .7s ease-in-out,visibility .7s ease-in-out}.expanded-content{display:flex;flex-wrap:wrap;gap:1rem;background-color:#ab0e5b;padding:1rem;visibility:hidden;transition:opacity .7s ease-in-out,visibility .7s ease-in-out}.expanded-content .container p{margin:0;font-size:.9rem;visibility:visible;transition:opacity .7s ease-in-out,visibility .7s ease-in-out}.expanded-content{display:flex;flex-wrap:wrap;gap:1rem;background-color:#ab0e5b;padding:1rem;border-radius:4px;visibility:visible;transition:opacity .7s ease-in-out,visibility .7s ease-in-out;transition:background-color .3s ease,border-color .3s ease}.expanded-content .container{flex:1 1 calc(25% - 1rem);min-width:150px;background-color:#fff;border-radius:4px;padding:.5rem;box-shadow:0 2px 4px #0000001a;transition:opacity .7s ease-in-out,visibility .7s ease-in-out}.expanded-content .container:hover{background-color:#f0f0f0;box-shadow:0 4px 8px #00000026;transform:translateY(-2px)}.rectangular-container{display:grid;grid-template-columns:repeat(3,1fr);gap:15px;padding:20px;background-color:#f9f9f9;border-radius:8px;box-shadow:0 4px 8px #0000001a}.info-box{background:#fff;border:1px solid #ececec;border-radius:6px;box-shadow:0 5px 10px #00000026;padding:10px 15px;transition:transform .2s,box-shadow .2s}.info-box:hover{transform:translateY(-5px);box-shadow:0 8px 15px #00000040}.info-box p{margin:0;font-family:Arial,sans-serif;font-size:14px;color:#333}strong.container{color:#af0f4f;font-weight:700}.svg_icon{width:1.5rem;display:flex;margin-top:-1.7rem;margin-left:13.5rem}\n"] }]
        }], propDecorators: { data: [{
                type: Input
            }], columns: [{
                type: Input
            }] } });

class SsrTableModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SsrTableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: SsrTableModule, declarations: [SsrTableComponent], imports: [FormsModule,
            BrowserModule,
            BrowserAnimationsModule], exports: [SsrTableComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SsrTableModule, imports: [FormsModule,
            BrowserModule,
            BrowserAnimationsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SsrTableModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        SsrTableComponent
                    ],
                    imports: [
                        FormsModule,
                        BrowserModule,
                        BrowserAnimationsModule
                    ],
                    exports: [
                        SsrTableComponent
                    ]
                }]
        }] });

/*
 * Public API Surface of ssr-table
 */

/**
 * Generated bundle index. Do not edit.
 */

export { SsrTableComponent, SsrTableModule, SsrTableService };
//# sourceMappingURL=ssr-table.mjs.map
